@@ -6,7 +6,7 @@ __copyright__ = "Copyright 2015, Janne Kario"
 __deprecated__ = False
 __license__ = "MIT"
 __status__ = "Production"
-__version__ = "1.2.7"
+__version__ = "1.2.8"
 
 
 class AppFilter(logging.Filter):
@@ -31,17 +31,17 @@ def configure_logging(debug: bool = False):
     logger.addFilter(AppFilter())
     logger.propagate = False
     syslog = logging.StreamHandler()
-    syslog.setLevel(logging.DEBUG)
+    syslog.setLevel(logging.INFO)
+    logger.setLevel(logging.INFO)
 
     formatter = logging.Formatter(
-        '%(asctime)s :: %(app_version)s :: %(message)s', "%Y-%m-%d %H:%M:%S"
+        '%(asctime)s.%(msecs)03d :: %(app_version)s :: %(message)s', "%Y-%m-%d %H:%M:%S"
     )
     syslog.setFormatter(formatter)
 
     if debug:
         logger.setLevel(logging.DEBUG)
-    else:
-        logger.setLevel(logging.INFO)
+        syslog.setLevel(logging.DEBUG)
 
     # add the handlers to logger
     logger.addHandler(syslog)
