@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 """
 Vedirect Exceptions.
 
@@ -20,7 +19,6 @@ class SettingInvalidException(Exception):
 
     .. seealso:: Settings
     """
-    pass
 
 
 class InputReadException(Exception):
@@ -29,7 +27,6 @@ class InputReadException(Exception):
 
     .. seealso:: Settings
     """
-    pass
 
 
 class TimeoutException(Exception):
@@ -38,7 +35,6 @@ class TimeoutException(Exception):
 
     .. seealso:: Settings
     """
-    pass
 
 
 class VedirectException(Exception):
@@ -47,4 +43,3 @@ class VedirectException(Exception):
 
     .. seealso:: Settings
     """
-    pass
